@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2016-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2016-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -35,15 +35,11 @@ class ParseProxyError(Exception):
 
     """Error while parsing PAC result string."""
 
-    pass
-
 
 class EvalProxyError(Exception):
 
     """Error while evaluating PAC script."""
 
-    pass
-
 
 def _js_slot(*args):
     """Wrap a methods as a JavaScript function.
@@ -146,7 +142,8 @@ class PACResolver:
         config = [c.strip() for c in proxy_str.split(' ') if c]
         if not config:
             raise ParseProxyError("Empty proxy entry")
-        elif config[0] == "DIRECT":
+
+        if config[0] == "DIRECT":
             if len(config) != 1:
                 raise ParseProxyError("Invalid number of parameters for " +
                                       "DIRECT")
@@ -184,6 +181,8 @@ class PACResolver:
         """
         self._engine = QJSEngine()
 
+        self._engine.installExtensions(QJSEngine.ConsoleExtension)
+
         self._ctx = _PACContext(self._engine)
         self._engine.globalObject().setProperty(
             "PAC", self._engine.newQObject(self._ctx))
@@ -210,6 +209,8 @@ class PACResolver:
         Return:
             A list of QNetworkProxy objects in order of preference.
         """
+        qtutils.ensure_valid(query.url())
+
         if from_file:
             string_flags = QUrl.PrettyDecoded
         else:
