@@ -38,8 +38,7 @@ from qutebrowser.config import configexc, config, configdata, configutils
 from qutebrowser.keyinput import keyutils
 from qutebrowser.utils import standarddir, utils, qtutils, log, urlmatch
 
-MYPY = False
-if MYPY:
+if typing.TYPE_CHECKING:
     # pylint: disable=unused-import, useless-suppression
     from qutebrowser.misc import savemanager
 
@@ -154,6 +153,9 @@ class YamlConfig(QObject):
         data = {'config_version': self.VERSION, 'settings': settings}
         with qtutils.savefile_open(self._filename) as f:
             f.write(textwrap.dedent("""
+                # If a config.py file exists, this file is ignored unless it's explicitly loaded
+                # via config.load_autoconfig(). For more information, see:
+                # https://github.com/qutebrowser/qutebrowser/blob/master/doc/help/configuring.asciidoc#loading-autoconfigyml
                 # DO NOT edit this file by hand, qutebrowser will overwrite it.
                 # Instead, create a config.py - see :help for details.
 
@@ -480,8 +482,9 @@ class ConfigPyWriter:
     def __init__(
             self,
             options: typing.List,
-            bindings: typing.MutableMapping[str, typing.Mapping[str, str]], *,
-            commented: bool) -> None:
+            bindings: typing.MutableMapping[
+                str, typing.Mapping[str, typing.Optional[str]]],
+            *, commented: bool) -> None:
         self._options = options
         self._bindings = bindings
         self._commented = commented
@@ -566,15 +569,23 @@ class ConfigPyWriter:
         if normal_bindings:
             yield self._line('# Bindings for normal mode')
             for key, command in sorted(normal_bindings.items()):
-                yield self._line('config.bind({!r}, {!r})'.format(
-                    key, command))
+                if command is None:
+                    yield self._line('config.unbind({!r})'.format(key))
+                else:
+                    yield self._line('config.bind({!r}, {!r})'.format(
+                        key, command))
             yield ''
 
         for mode, mode_bindings in sorted(self._bindings.items()):
             yield self._line('# Bindings for {} mode'.format(mode))
             for key, command in sorted(mode_bindings.items()):
-                yield self._line('config.bind({!r}, {!r}, mode={!r})'.format(
-                    key, command, mode))
+                if command is None:
+                    yield self._line('config.unbind({!r}, mode={!r})'.format(
+                        key, mode))
+                else:
+                    yield self._line(
+                        'config.bind({!r}, {!r}, mode={!r})'.format(
+                            key, command, mode))
             yield ''
 
 
@@ -635,6 +646,7 @@ def read_config_py(filename: str, raising: bool = False) -> None:
             exception=e, traceback=traceback.format_exc()))
 
     api.finalize()
+    config.instance.config_py_loaded = True
 
     if api.errors:
         raise configexc.ConfigFileErrors('config.py', api.errors)
