@@ -60,7 +60,7 @@
         details.method = details.method ? details.method.toUpperCase() : "GET";
 
         if (!details.url) {
-            throw new Error("GM_xmlhttpRequest requires an URL.");
+            throw new Error("GM_xmlhttpRequest requires a URL.");
         }
 
         // build XMLHttpRequest object
@@ -100,7 +100,7 @@
 
         const head = document.getElementsByTagName("head")[0];
         if (head === undefined) {
-            // no head yet, stick it whereever
+            // no head yet, stick it wherever
             document.documentElement.appendChild(oStyle);
         } else {
             head.appendChild(oStyle);
