@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -29,9 +29,9 @@ import urllib.parse
 from PyQt5.QtCore import QUrl, QUrlQuery
 from PyQt5.QtNetwork import QHostInfo, QHostAddress, QNetworkProxy
 
+from qutebrowser.api import cmdutils
 from qutebrowser.config import config
 from qutebrowser.utils import log, qtutils, message, utils
-from qutebrowser.commands import cmdexc
 from qutebrowser.browser.network import pac
 
 
@@ -54,13 +54,9 @@ WEBENGINE_SCHEMES = [
 ]
 
 
-class InvalidUrlError(ValueError):
+class InvalidUrlError(Exception):
 
-    """Error raised if a function got an invalid URL.
-
-    Inherits ValueError because that was the exception originally used for
-    that, so there still might be some code around which checks for that.
-    """
+    """Error raised if a function got an invalid URL."""
 
     def __init__(self, url):
         if url.isValid():
@@ -116,7 +112,8 @@ def _get_search_url(txt):
     if engine is None:
         engine = 'DEFAULT'
     template = config.val.url.searchengines[engine]
-    url = qurl_from_user_input(template.format(urllib.parse.quote(term)))
+    quoted_term = urllib.parse.quote(term, safe='')
+    url = qurl_from_user_input(template.format(quoted_term))
 
     if config.val.url.open_base_url and term in config.val.url.searchengines:
         url = qurl_from_user_input(config.val.url.searchengines[term])
@@ -217,8 +214,7 @@ def fuzzy_url(urlstr, cwd=None, relative=False, do_search=True,
     if do_search and config.val.url.auto_search != 'never' and urlstr:
         qtutils.ensure_valid(url)
     else:
-        if not url.isValid():
-            raise InvalidUrlError(url)
+        ensure_valid(url)
     return url
 
 
@@ -343,6 +339,11 @@ def qurl_from_user_input(urlstr):
         return QUrl('http://[{}]{}'.format(ipstr, rest))
 
 
+def ensure_valid(url):
+    if not url.isValid():
+        raise InvalidUrlError(url)
+
+
 def invalid_url_error(url, action):
     """Display an error message for a URL.
 
@@ -359,8 +360,10 @@ def invalid_url_error(url, action):
 
 def raise_cmdexc_if_invalid(url):
     """Check if the given QUrl is invalid, and if so, raise a CommandError."""
-    if not url.isValid():
-        raise cmdexc.CommandError(get_errstring(url))
+    try:
+        ensure_valid(url)
+    except InvalidUrlError as e:
+        raise cmdutils.CommandError(str(e))
 
 
 def get_path_if_valid(pathstr, cwd=None, relative=False, check_exists=False):
@@ -433,8 +436,7 @@ def host_tuple(url):
 
     This is suitable to identify a connection, e.g. for SSL errors.
     """
-    if not url.isValid():
-        raise InvalidUrlError(url)
+    ensure_valid(url)
     scheme, host, port = url.scheme(), url.host(), url.port()
     assert scheme
     if not host:
@@ -483,10 +485,8 @@ def same_domain(url1, url2):
     Return:
         True if the domains are the same, False otherwise.
     """
-    if not url1.isValid():
-        raise InvalidUrlError(url1)
-    if not url2.isValid():
-        raise InvalidUrlError(url2)
+    ensure_valid(url1)
+    ensure_valid(url2)
 
     suffix1 = url1.topLevelDomain()
     suffix2 = url2.topLevelDomain()
@@ -510,100 +510,6 @@ def encoded_url(url):
     return bytes(url.toEncoded()).decode('ascii')
 
 
-class IncDecError(Exception):
-
-    """Exception raised by incdec_number on problems.
-
-    Attributes:
-        msg: The error message.
-        url: The QUrl which caused the error.
-    """
-
-    def __init__(self, msg, url):
-        super().__init__(msg)
-        self.url = url
-        self.msg = msg
-
-    def __str__(self):
-        return '{}: {}'.format(self.msg, self.url.toString())
-
-
-def _get_incdec_value(match, incdec, url, count):
-    """Get an incremented/decremented URL based on a URL match."""
-    pre, zeroes, number, post = match.groups()
-    # This should always succeed because we match \d+
-    val = int(number)
-    if incdec == 'decrement':
-        if val <= 0:
-            raise IncDecError("Can't decrement {}!".format(val), url)
-        val -= count
-    elif incdec == 'increment':
-        val += count
-    else:
-        raise ValueError("Invalid value {} for indec!".format(incdec))
-    if zeroes:
-        if len(number) < len(str(val)):
-            zeroes = zeroes[1:]
-        elif len(number) > len(str(val)):
-            zeroes += '0'
-
-    return ''.join([pre, zeroes, str(val), post])
-
-
-def incdec_number(url, incdec, count=1, segments=None):
-    """Find a number in the url and increment or decrement it.
-
-    Args:
-        url: The current url
-        incdec: Either 'increment' or 'decrement'
-        count: The number to increment or decrement by
-        segments: A set of URL segments to search. Valid segments are:
-                  'host', 'port', 'path', 'query', 'anchor'.
-                  Default: {'path', 'query'}
-
-    Return:
-        The new url with the number incremented/decremented.
-
-    Raises IncDecError if the url contains no number.
-    """
-    if not url.isValid():
-        raise InvalidUrlError(url)
-
-    if segments is None:
-        segments = {'path', 'query'}
-    valid_segments = {'host', 'port', 'path', 'query', 'anchor'}
-    if segments - valid_segments:
-        extra_elements = segments - valid_segments
-        raise IncDecError("Invalid segments: {}".format(
-            ', '.join(extra_elements)), url)
-
-    # Make a copy of the QUrl so we don't modify the original
-    url = QUrl(url)
-    # Order as they appear in a URL
-    segment_modifiers = [
-        ('host', url.host, url.setHost),
-        ('port', lambda: str(url.port()) if url.port() > 0 else '',
-         lambda x: url.setPort(int(x))),
-        ('path', url.path, url.setPath),
-        ('query', url.query, url.setQuery),
-        ('anchor', url.fragment, url.setFragment),
-    ]
-    # We're searching the last number so we walk the url segments backwards
-    for segment, getter, setter in reversed(segment_modifiers):
-        if segment not in segments:
-            continue
-
-        # Get the last number in a string
-        match = re.fullmatch(r'(.*\D|^)(0*)(\d+)(.*)', getter())
-        if not match:
-            continue
-
-        setter(_get_incdec_value(match, incdec, url, count))
-        return url
-
-    raise IncDecError("No number found in URL!", url)
-
-
 def file_url(path):
     """Return a file:// url (as string) to the given local path.
 
@@ -630,8 +536,7 @@ def safe_display_string(qurl):
     See https://github.com/qutebrowser/qutebrowser/issues/2547
     and https://bugreports.qt.io/browse/QTBUG-60365
     """
-    if not qurl.isValid():
-        raise InvalidUrlError(qurl)
+    ensure_valid(qurl)
 
     host = qurl.host(QUrl.FullyEncoded)
     if '..' in host:  # pragma: no cover
@@ -674,8 +579,7 @@ def proxy_from_url(url):
     Return:
         New QNetworkProxy.
     """
-    if not url.isValid():
-        raise InvalidUrlError(url)
+    ensure_valid(url)
 
     scheme = url.scheme()
     if scheme in ['pac+http', 'pac+https', 'pac+file']:
